@@ -116,6 +116,7 @@ func main() {
 	configRules = append(configRules, rules.NPM())
 	configRules = append(configRules, rules.NytimesAccessToken())
 	configRules = append(configRules, rules.OktaAccessToken())
+	configRules = append(configRules, rules.OpenAI())
 	configRules = append(configRules, rules.PlaidAccessID())
 	configRules = append(configRules, rules.PlaidSecretKey())
 	configRules = append(configRules, rules.PlaidAccessToken())
@@ -142,8 +143,16 @@ func main() {
 	configRules = append(configRules, rules.ShopifySharedSecret())
 	configRules = append(configRules, rules.SidekiqSecret())
 	configRules = append(configRules, rules.SidekiqSensitiveUrl())
-	configRules = append(configRules, rules.SlackAccessToken())
-	configRules = append(configRules, rules.SlackWebHook())
+	configRules = append(configRules, rules.SlackBotToken())
+	configRules = append(configRules, rules.SlackUserToken())
+	configRules = append(configRules, rules.SlackAppLevelToken())
+	configRules = append(configRules, rules.SlackConfigurationToken())
+	configRules = append(configRules, rules.SlackConfigurationRefreshToken())
+	configRules = append(configRules, rules.SlackLegacyBotToken())
+	configRules = append(configRules, rules.SlackLegacyWorkspaceToken())
+	configRules = append(configRules, rules.SlackLegacyToken())
+	configRules = append(configRules, rules.SlackWebHookUrl())
+	configRules = append(configRules, rules.Snyk())
 	configRules = append(configRules, rules.StripeAccessToken())
 	configRules = append(configRules, rules.SquareAccessToken())
 	configRules = append(configRules, rules.SquareSpaceAccessToken())
